@@ -24,7 +24,7 @@
 #include <QDialog>
 #include <QDialogButtonBox>
 #include <QVBoxLayout>
-#include <QRegExpValidator>
+#include <QRegularExpressionValidator>
 
 class AskName : public QDialog
 {
@@ -32,7 +32,7 @@ class AskName : public QDialog
         AskName(const QString& text, QWidget* parent) : QDialog(parent)
         {
             edit=new QLineEdit(this);
-            edit->setValidator(new QRegExpValidator(QRegExp(QStringLiteral("[a-zA-Z][\\w]*")), edit));
+            edit->setValidator(new QRegularExpressionValidator(QRegularExpression(QStringLiteral("[a-zA-Z][\\w]*")), edit));
             
             QDialogButtonBox * buttonBox;
             QVBoxLayout *items=new QVBoxLayout(this);
